<?php

/**
 * This class adds a widget to display on sidebar.
 */

class CleverWidget extends WP_Widget {

  public $args = array(
      'before_title'  => '<h4 class="widgettitle">',
      'after_title'   => '</h4>',
      'before_widget' => '<div class="widget-wrap">',
      'after_widget'  => '</div></div>'
  );

  public function __construct() {
    parent::__construct(
        'clever-whatsapp-widget',
        'Clever WhatsApp'
    );

    add_action( 'widgets_init', function() {
        register_widget( 'CleverWidget' );
    });
  }

  public function widget( $args, $instance ) {
    echo $args['before_widget'];
    if ( ! empty( $instance['title'] ) ) {
      echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
    }
    if (count($instance['account_id_list'])) {
      echo '<div class="cleverwa-widget">';
      foreach ($instance['account_id_list'] as $id) {
        echo do_shortcode('[cleverwa_button id="'.$id.'"]');
      }
      echo '</div>';
    }
    echo $args['after_widget'];
  }

  public function form( $instance ) {
    $title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( '', 'cleverwa' );
    $account_id_list = ! empty( $instance['account_id_list'] ) ? $instance['account_id_list'] : array();
    $accounts = get_posts(
      array(
  			'posts_per_page' => -1,
        'post_type' => 'cleverwa_accounts',
      )
    );
    ?>
      <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php echo esc_html__( 'Title:', 'cleverwa' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
      </p>
      <p><?php esc_html_e( 'Select one or more accounts to display on the widget.', 'cleverwa' ); ?></p>
      <p>
        <select class="widefat" id="<?php echo esc_attr($this->get_field_id('account_id_list')); ?>" name="<?php echo esc_attr($this->get_field_name('account_id_list')); ?>[]" multiple>
          <?php
            foreach( $accounts as $account ) {
              $is_selected = (in_array($account->ID, $account_id_list)) ? ' selected' : '';
              echo '<option value="' . esc_attr($account->ID) . '"' . esc_attr($is_selected) . '>' . esc_html($account->post_title) . '</option>' . "\n";
            }
          ?>
        </select>
      </p>
    <?php
  }

  public function update( $new_instance, $old_instance ) {

    $instance = array();

    $instance['title'] = ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
    $instance['account_id_list'] = isset( $new_instance['account_id_list'] ) ? $new_instance['account_id_list'] : array();

    return $instance;
  }

}
